==> gsasl-1.9.2.tar.gz: gsasl-1.9.2/lib/saml20/saml20.h <==
/* saml20.h --- Prototypes for SAML20.
 * Copyright (C) 2010-2020 Simon Josefsson
 *
 * This file is part of GNU SASL Library.
 *
 * GNU SASL Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * GNU SASL Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GNU SASL Library; if not, write to the Free
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef SAML20_H
#define SAML20_H

#include <gsasl.h>

#define GSASL_SAML20_NAME "SAML20"

extern Gsasl_mechanism gsasl_saml20_mechanism;

extern int _gsasl_saml20_client_start (Gsasl_session * sctx,
				       void **mech_data);

extern int _gsasl_saml20_client_step (Gsasl_session * sctx,
				      void *mech_data,
				      const char *input, size_t input_len,
				      char **output, size_t *output_len);

extern void _gsasl_saml20_client_finish (Gsasl_session * sctx,
					 void *mech_data);

extern int _gsasl_saml20_server_start (Gsasl_session * sctx,
				       void **mech_data);

extern int _gsasl_saml20_server_step (Gsasl_session * sctx,
				      void *mech_data,
				      const char *input, size_t input_len,
				      char **output, size_t *output_len);

extern void _gsasl_saml20_server_finish (Gsasl_session * sctx,
					 void *mech_data);

#endif /* SAML20_H */

==> gsasl-1.11.2.tar.gz: gsasl-1.11.2/lib/saml20/saml20.h <==
/* saml20.h --- Prototypes for SAML20.
 * Copyright (C) 2010-2021 Simon Josefsson
 *
 * This file is part of GNU SASL Library.
 *
 * GNU SASL Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * GNU SASL Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GNU SASL Library; if not, write to the Free
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef SAML20_H
# define SAML20_H

# include <gsasl.h>

# define GSASL_SAML20_NAME "SAML20"

extern Gsasl_mechanism _gsasl_saml20_mechanism;

extern int _gsasl_saml20_client_start (Gsasl_session * sctx,
				       void **mech_data);

extern int _gsasl_saml20_client_step (Gsasl_session * sctx,
				      void *mech_data,
				      const char *input, size_t input_len,
				      char **output, size_t *output_len);

extern void _gsasl_saml20_client_finish (Gsasl_session * sctx,
					 void *mech_data);

extern int _gsasl_saml20_server_start (Gsasl_session * sctx,
				       void **mech_data);

extern int _gsasl_saml20_server_step (Gsasl_session * sctx,
				      void *mech_data,
				      const char *input, size_t input_len,
				      char **output, size_t *output_len);

extern void _gsasl_saml20_server_finish (Gsasl_session * sctx,
					 void *mech_data);

#endif /* SAML20_H */
